@@ -20,7 +20,7 @@ BEGIN
     use Data::UUID;
     use JSON 4.03 qw( -convert_blessed_universally );
     use Module::Generic::File qw( file sys_tmpdir );
-    use Nice::Try;
+    # use Nice::Try;
     our $HAS_CACHE_MMAP = 0;
     our $VERSION = 'v0.1.2';
 };
@@ -55,7 +55,9 @@ sub init
     # A cache file will be provided either by the user, either by us with the open() method.
     if( my $f = $self->cache_file )
     {
-        try
+        # try-catch
+        local $@;
+        eval
         {
             # No serialiser because we manage ths ourself
             my $cache = Cache::FastMmap->new(
@@ -66,17 +68,20 @@ sub init
                 serializer => '',
             );
             $self->{_cache} = $cache;
-        }
-        catch( $e )
+        };
+        if( $@ )
         {
-            return( $self->error( "Error trying to instantiate a Cache::FastMmap object: $e" ) );
+            return( $self->error( "Error trying to instantiate a Cache::FastMmap object: $@" ) );
         }
     }
-    $self->{owner}      = $$;
-    $self->{removed}    = 0;
+    $self->{owner} = $$;
+    $self->{removed} = 0;
     return( $self );
 }
 
+# This class does not convert to an HASH
+sub as_hash { return( $_[0] ); }
+
 sub base64 { return( shift->_set_get_scalar( 'base64', @_ ) ); }
 
 sub cache_file { return( shift->_set_get_file( 'cache_file', @_ ) ); }
@@ -274,13 +279,15 @@ sub read
     my $key = $self->key || return( $self->error( "No key set." ) );
     my $cache = $self->_cache || return( $self->error( "No Cache::FastMmap object. It seems it is gone!" ) );
     my $buffer;
-    try
+    # try-catch
+    local $@;
+    eval
     {
         $buffer = $cache->get( $key );
-    }
-    catch( $e )
+    };
+    if( $@ )
     {
-        return( $self->error( "Error retrieving data in MMap file for key '$key': $e" ) );
+        return( $self->error( "Error retrieving data in MMap file for key '$key': $@" ) );
     }
     my $bytes = CORE::length( $buffer // '' );
     my $packing = $self->_packing_method;
@@ -299,7 +306,9 @@ sub read
             substr( $buffer, $len, length( $buffer ), '' );
         }
 
-        try
+        # try-catch
+        local $@;
+        eval
         {
             if( $packing eq 'json' )
             {
@@ -333,10 +342,10 @@ sub read
                     ( defined( $self->{base64} ) ? ( base64 => $self->{base64} ) : () ),
                 );
             }
-        }
-        catch( $e )
+        };
+        if( $@ )
         {
-            return( $self->error( "An error occured while decoding data using $packing with base64 set to '", ( $self->{base64} // '' ), "': $e" ) );
+            return( $self->error( "An error occured while decoding data using $packing with base64 set to '", ( $self->{base64} // '' ), "': $@" ) );
         }
     }
     else
@@ -440,62 +449,93 @@ sub write
     my $cache = $self->_cache || return( $self->error( "No Cache::FastMmap object. It seems it is gone!" ) );
     my $packing = $self->_packing_method;
     my $encoded;
-    try
+    if( $packing eq 'json' )
     {
-        if( $packing eq 'json' )
+        # try-catch
+        local $@;
+        eval
         {
             $encoded = $self->_encode_json( $data );
+        };
+        if( $@ )
+        {
+            return( $self->error( "An error occured encoding data provided using $packing: $@. Data was: '$data'" ) );
         }
-        elsif( $packing eq 'cbor' )
+    }
+    elsif( $packing eq 'cbor' )
+    {
+        # try-catch
+        local $@;
+        eval
         {
             $encoded = $self->serialise( $data,
                 serialiser => 'CBOR::XS',
                 allow_sharing => 1,
                 ( defined( $self->{base64} ) ? ( base64 => $self->{base64} ) : () ),
             );
-            return( $self->pass_error ) if( !defined( $encoded ) );
+        };
+        if( $@ )
+        {
+            return( $self->error( "An error occured encoding data provided using $packing: $@. Data was: '$data'" ) );
         }
-        elsif( $packing eq 'sereal' )
+        return( $self->pass_error ) if( !defined( $encoded ) );
+    }
+    elsif( $packing eq 'sereal' )
+    {
+        $self->_load_class( 'Sereal::Encoder' ) || return( $self->pass_error );
+        my $const;
+        $const = \&{"Sereal\::Encoder::SRL_ZLIB"} if( defined( &{"Sereal\::Encoder::SRL_ZLIB"} ) );
+        # try-catch
+        local $@;
+        eval
         {
-            $self->_load_class( 'Sereal::Encoder' ) || return( $self->pass_error );
-            my $const;
-            $const = \&{"Sereal\::Encoder::SRL_ZLIB"} if( defined( &{"Sereal\::Encoder::SRL_ZLIB"} ) );
             $encoded = $self->serialise( $data,
                 serialiser => 'Sereal',
                 freeze_callbacks => 1,
                 ( defined( $const ) ? ( compress => $const->() ) : () ),
                 ( defined( $self->{base64} ) ? ( base64 => $self->{base64} ) : () ),
             );
-            return( $self->pass_error ) if( !defined( $encoded ) );
+        };
+        if( $@ )
+        {
+            return( $self->error( "An error occured encoding data provided using $packing: $@. Data was: '$data'" ) );
         }
-        # Default to Storable::Improved
-        else
+        return( $self->pass_error ) if( !defined( $encoded ) );
+    }
+    # Default to Storable::Improved
+    else
+    {
+        # try-catch
+        local $@;
+        # local $Storable::forgive_me = 1;
+        # $encoded = Storable::Improved::freeze( $data );
+        eval
         {
-            # local $Storable::forgive_me = 1;
-            # $encoded = Storable::Improved::freeze( $data );
             $encoded = $self->serialise( $data,
                 serialiser => 'Storable::Improved',
                 ( defined( $self->{base64} ) ? ( base64 => $self->{base64} ) : () ),
             );
-            return( $self->pass_error ) if( !defined( $encoded ) );
+        };
+        if( $@ )
+        {
+            return( $self->error( "An error occured encoding data provided using $packing: $@. Data was: '$data'" ) );
         }
+        return( $self->pass_error ) if( !defined( $encoded ) );
     }
-    catch( $e )
-    {
-        return( $self->error( "An error occured encoding data provided using $packing: $e. Data was: '$data'" ) );
-    }
-    
+
     # Simple encapsulation
     # FYI: MG = Module::Generic
     substr( $encoded, 0, 0, 'MG[' . length( $encoded ) . ']' );
     
-    try
+    # try-catch
+    local $@;
+    eval
     {
         $cache->set( $key => $encoded );
-    }
-    catch( $e )
+    };
+    if( $@ )
     {
-        return( $self->error( "Error writing data to MMap file for key '$key': $e" ) );
+        return( $self->error( "Error writing data to MMap file for key '$key': $@" ) );
     }
     return( $self );
 }
@@ -542,16 +582,19 @@ sub _decode_json
         return( $this );
     };
     
-    try
+    my $decoded;
+    # try-catch
+    local $@;
+    eval
     {
-        my $decoded = $j->decode( $data );
-        my $result = $crawl->( $decoded );
-        return( $result );
-    }
-    catch( $e )
+        $decoded = $j->decode( $data );
+    };
+    if( $@ )
     {
-        return( $self->error( "An error occurred while trying to decode JSON data: $e" ) );
+        return( $self->error( "An error occurred while trying to decode JSON data: $@" ) );
     }
+    my $result = $crawl->( $decoded );
+    return( $result );
 }
 
 # Purpose of this method is to recursively check the given data and change scalar reference if they are anything else than 1 or 0, otherwise JSON would complain
@@ -609,15 +652,19 @@ sub _encode_json
     };
     my $ref = $crawl->( $data );
     my $j = JSON->new->utf8->relaxed->allow_nonref->convert_blessed;
-    try
+    
+    my $encoded;
+    # try-catch
+    local $@;
+    eval
     {
-        my $encoded = $j->encode( $ref );
-        return( $encoded );
-    }
-    catch( $e )
+        $encoded = $j->encode( $ref );
+    };
+    if( $@ )
     {
-        return( $self->error( "An error occurred while trying to JSON encode data: $e" ) );
+        return( $self->error( "An error occurred while trying to JSON encode data: $@" ) );
     }
+    return( $encoded );
 }
 
 sub _packing_method { return( shift->_set_get_scalar( '_packing_method', @_ ) ); }
